==> mypy_boto3_marketplace_entitlement-1.22.0-py3-none-any.whl: mypy_boto3_marketplace_entitlement/type_defs.py <==
"""
Type annotations for marketplace-entitlement service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_marketplace_entitlement/type_defs/)

Usage::

    ```python
    from mypy_boto3_marketplace_entitlement.type_defs import EntitlementTypeDef

    data: EntitlementTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence

from .literals import GetEntitlementFilterNameType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "EntitlementTypeDef",
    "EntitlementValueTypeDef",
    "GetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    "GetEntitlementsRequestRequestTypeDef",
    "GetEntitlementsResultTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
)

EntitlementTypeDef = TypedDict(
    "EntitlementTypeDef",
    {
        "ProductCode": str,
        "Dimension": str,
        "CustomerIdentifier": str,
        "Value": "EntitlementValueTypeDef",
        "ExpirationDate": datetime,
    },
    total=False,
)

EntitlementValueTypeDef = TypedDict(
    "EntitlementValueTypeDef",
    {
        "IntegerValue": int,
        "DoubleValue": float,
        "BooleanValue": bool,
        "StringValue": str,
    },
    total=False,
)

_RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef = TypedDict(
    "_RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    {
        "ProductCode": str,
    },
)
_OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef = TypedDict(
    "_OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    {
        "Filter": Mapping[GetEntitlementFilterNameType, Sequence[str]],
        "PaginationConfig": "PaginatorConfigTypeDef",
    },
    total=False,
)


class GetEntitlementsRequestGetEntitlementsPaginateTypeDef(
    _RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef,
    _OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef,
):
    pass


_RequiredGetEntitlementsRequestRequestTypeDef = TypedDict(
    "_RequiredGetEntitlementsRequestRequestTypeDef",
    {
        "ProductCode": str,
    },
)
_OptionalGetEntitlementsRequestRequestTypeDef = TypedDict(
    "_OptionalGetEntitlementsRequestRequestTypeDef",
    {
        "Filter": Mapping[GetEntitlementFilterNameType, Sequence[str]],
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)


class GetEntitlementsRequestRequestTypeDef(
    _RequiredGetEntitlementsRequestRequestTypeDef, _OptionalGetEntitlementsRequestRequestTypeDef
):
    pass


GetEntitlementsResultTypeDef = TypedDict(
    "GetEntitlementsResultTypeDef",
    {
        "Entitlements": List["EntitlementTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

==> mypy_boto3_marketplace_entitlement-1.28.12-py3-none-any.whl: mypy_boto3_marketplace_entitlement/type_defs.py <==
"""
Type annotations for marketplace-entitlement service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_marketplace_entitlement/type_defs/)

Usage::

    ```python
    from mypy_boto3_marketplace_entitlement.type_defs import EntitlementValueTypeDef

    data: EntitlementValueTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence

from .literals import GetEntitlementFilterNameType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "EntitlementValueTypeDef",
    "GetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    "GetEntitlementsRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
    "EntitlementTypeDef",
    "GetEntitlementsResultTypeDef",
)

EntitlementValueTypeDef = TypedDict(
    "EntitlementValueTypeDef",
    {
        "IntegerValue": int,
        "DoubleValue": float,
        "BooleanValue": bool,
        "StringValue": str,
    },
    total=False,
)

_RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef = TypedDict(
    "_RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    {
        "ProductCode": str,
    },
)
_OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef = TypedDict(
    "_OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef",
    {
        "Filter": Mapping[GetEntitlementFilterNameType, Sequence[str]],
        "PaginationConfig": "PaginatorConfigTypeDef",
    },
    total=False,
)


class GetEntitlementsRequestGetEntitlementsPaginateTypeDef(
    _RequiredGetEntitlementsRequestGetEntitlementsPaginateTypeDef,
    _OptionalGetEntitlementsRequestGetEntitlementsPaginateTypeDef,
):
    pass


_RequiredGetEntitlementsRequestRequestTypeDef = TypedDict(
    "_RequiredGetEntitlementsRequestRequestTypeDef",
    {
        "ProductCode": str,
    },
)
_OptionalGetEntitlementsRequestRequestTypeDef = TypedDict(
    "_OptionalGetEntitlementsRequestRequestTypeDef",
    {
        "Filter": Mapping[GetEntitlementFilterNameType, Sequence[str]],
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)


class GetEntitlementsRequestRequestTypeDef(
    _RequiredGetEntitlementsRequestRequestTypeDef, _OptionalGetEntitlementsRequestRequestTypeDef
):
    pass


PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

EntitlementTypeDef = TypedDict(
    "EntitlementTypeDef",
    {
        "ProductCode": str,
        "Dimension": str,
        "CustomerIdentifier": str,
        "Value": EntitlementValueTypeDef,
        "ExpirationDate": datetime,
    },
    total=False,
)

GetEntitlementsResultTypeDef = TypedDict(
    "GetEntitlementsResultTypeDef",
    {
        "Entitlements": List[EntitlementTypeDef],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)
